@@ -1,4 +1,5 @@
 from infi.wioctl.structures import *
+from infi.instruct import VarSizeArray, ReadPointer
 
 class SCSI_ADDRESS(Struct):
     _fields_ = [DWORD("Length"), BYTE("PortNumber"), BYTE("PathId"), BYTE("TargetId"), BYTE("Lun")]
@@ -15,3 +16,11 @@ class DISK_GEOMETRY(Struct):
 class DISK_GEOMETRY_EX(Struct):
     _fields_ = [Field("Geometry", DISK_GEOMETRY), Field("DiskSize", LARGE_INTEGER),
                ]# it is actually a variable-length structure, but we don't care about the rest
+
+class DISK_EXTENT(Struct):
+    _fields_ = [DWORD("DiskNumber"), DWORD("Padding"), Field("StartingOffset", LARGE_INTEGER),
+                Field("ExtentLength", LARGE_INTEGER)]
+
+class VOLUME_DISK_EXTENTS(Struct):
+    _fields_ = [DWORD("NumberOfDiskExtents"), DWORD("Padding"),
+                VarSizeArray("Extents", ReadPointer("NumberOfDiskExtents"), DISK_EXTENT)]
